********************************************************
***Replication code for 
***"Change in Maternal Well-Being 
***during COVID-19 Pandemic: Did Pre-Pandemic Social 
***Support and Parenting Stress Buffer or Aggravate 
***Mental Health Disparities among Lone and 
***Partnered Mothers in Germany?" 
***by
***Claudia Recksiedler, Christine Entleitner-Phleps, &
***Alexandra N. Langmeyer 
***in Journal of Family Research
********************************************************

version 15.1
set more off
capture log close
clear


********************************************************
**used pre-COVID data 2019: 
**https://doi.org/10.17621/aida2019
********************************************************

global aida2019 "\\Fileserver\Groups\FDZ\AIDA\2019_AIDA\generierte_Daten"
use "$aida2019\personen.dta", clear


********************************************************
**select sample at baseline
********************************************************

rename _all, lower
global output "\\Fileserver\Groups\Sonstiges\shared care\Journal of Family Research"
save "$output\aida2019.dta"


fre  m_befragt_in
keep if (m_befragt_in == 7) | (m_befragt_in == 9) | (m_befragt_in == 10) // only parents


fre geschlecht
keep if geschlecht == 2 // only mothers


fre k_familientyp_hh
recode k_familientyp_hh (4/5=1) (6/7=2) (9/15=3), gen(famtyp)
label define famtyp 1 "Lone parents" 2 "Two-parent families" 3 "Stepfamilies"
label values famtyp famtyp
tab  k_familientyp_hh famtyp


fre famtyp
drop if famtyp == 3 //only keep lone and partnered mothers
fre famtyp 

recode famtyp (2=0), gen(lone) //generate binary indicator for lone parent status
label define lone 0 "partnered" 1 "lone"
label values lone lone
tab famtyp lone


fre xalter
drop if xalter==89 //remove one unreasonably old mother


global output "\\Fileserver\Groups\Sonstiges\shared care\Journal of Family Research"
save "$output\aida2019mothers.dta"
clear


********************************************************
**used COVID-19 data:
**https://doi.org/10.17621/aida2021
********************************************************
global aida2021 "\\Fileserver\Groups\FDZ\AIDA\2021_AIDA\Enddatensatz28-06-2022"
use "$aida2021\personen.dta", clear


codebook, compact
keep INTNR k_IstETvonZP17 k_IstETvonZP interview_monat interview_jahr gebmon ///
gebjahr v44416 v44401_1 v44401_2 v44401_3 v44401_4 v44401_5 h91113
save "$output\aida2021_reduced.dta"


rename INTNR, lower
rename k_IstETvonZP17 k_IstETvonZP, lower
rename k_istetvonzp17 k_istetvonzp17_2021
rename k_istetvonzp k_istetvonzp_2021
rename interview_monat interview_monat_2021
rename interview_jahr interview_jahr_2021
rename gebmon gebmon_2021
rename gebjahr gebjahr_2021


*who5: psychological well-being (higher values=worse)
fre v44401_1 v44401_2 v44401_3 v44401_4 v44401_5
 
clonevar dep1_2021 = v44401_1 
clonevar dep2_2021 = v44401_2 
clonevar dep3_2021 = v44401_3 
clonevar dep4_2021 = v44401_4 
clonevar dep5_2021 = v44401_5 

alpha dep1_2021 dep2_2021 dep3_2021 dep4_2021 dep5_2021

factor dep1_2021 dep2_2021 dep3_2021 dep4_2021 dep5_2021, pcf

egen who5_2021 = rowmean(dep1_2021 - dep5_2021)
label var who5_2021 "mean score depression 2021" 

drop v44401_1 v44401_2 v44401_3 v44401_4 v44401_5

gen affect_2021 = 7 - who5_2021
tab affect_2021 who5_2021
fre who5_2021 affect_2021
drop who5_2021
 
label define affect 1 "at no time" 6 "all the time"
label values affect_2021 affect
label var affect_2021 "Who5 mean score recoded: higher values=better"
fre affect_2021


*life satisfaction 
fre v44416 
rename v44416 lifesat

gen sat_2021 = 7 - lifesat
tab sat_2021  lifesat
fre sat_2021  lifesat
drop lifesat
 
label define sat 1 "not satisfied at all" 6 "very satisfied"
label values sat_2021 sat
label var sat_2021 "Life satisfaction recocded: higher values=better"
fre sat_2021

sort intnr

save "$output\aida2021_reduced.dta", replace
clear


********************************************************
**merge waves
********************************************************

use "$output\aida2019mothers.dta", replace
sort intnr
merge 1:1 intnr using "$output\aida2021_reduced.dta"


bysort lone: fre _merge
drop if _merge==2 

save "$output\aida_panel.dta"


********************************************************
**Preparing indicators for models
********************************************************

**Psychological well-being in 2019
fre v44401_1 v44401_2 v44401_3 v44401_4 v44401_5

egen who5_2019 = rowmean(v44401_1 - v44401_5)
label var who5_2019 "mean score depression 2019" 

gen affect_2019 = 7 - who5_2019
tab affect_2019 who5_2019
fre who5_2019 affect_2019
 
label define affect 1 "at no time" 6 "all the time", replace
label values affect_2019 affect
label var affect_2019 "Who5 mean score recoded: higher values=better"
fre affect_2019


**Life satisfaction in 2019
fre h77100
gen sat_2019 = 7 - h77100
tab sat_2019  h77100
fre sat_2019  h77100
 
label define sat 1 "not satisfied at all" 6 "very satisfied", replace
label values sat_2019 sat
label var sat_2019 "Life satisfaction recoded: higher values=better"
fre sat_2019


**Change scores
gen affect_change =  affect_2021 - affect_2019

hist affect_change
fre affect_change


gen sat_change =  sat_2021 - sat_2019

hist sat_change, discrete
fre sat_change


**Parenting stress in 2019
fre v44414_1

gen stress = 7 - v44414_1
tab stress  v44414_1
fre stress  v44414_1
 
label define stress 1 "low" 6 "high"
label values stress stress
label var stress "Parenting stress recoded"
fre stress

tab stress v44414_1


**Social support in 2019
fre k_osscat_hh 
clonevar support = k_osscat_hh  

label define support 1 "poor" 2 "medium" 3 "strong"
label values support support
label var support "Social support scale"
tab support k_osscat_hh


**Covariates in 2019
*Education 
fre k_casmin
recode k_casmin (0/2=1) (3/4=2) (5/8=3), gen(edu3)
label define cas3 1 "primary" 2 "secondary" 3 "tertiary"
label values edu3 cas3
tab k_casmin edu3


*Number of children in household
fre k_anzkidshh
recode k_anzkidshh (1=1) (2=2) (3/7 = 3), gen(anzkid3)
label define anzkid3 1 "1 child" 2 "2 children" 3 "3+ children"
label values anzkid3 anzkid3
tab k_anzkidshh anzkid3


*Economic deprivation
tab k_deprivationsindex_hh, mi
recode k_deprivationsindex_hh (0 = 1) (1 = 2) (2/3 = 3), gen(depriv3)
label variable depriv3 "Index economic deprivation: 3 categories"
label define depriv3 ///
	1 "no" ///
	2 "low" ///
	3 "high"
label values depriv3 depriv3
tab k_deprivationsindex_hh depriv3


*Employment status
gen employ = .
replace employ = 1 if (k_aktiv ==210) | (k_aktiv ==400) | ///
(k_aktiv == 501) | (k_aktiv==502) | (k_aktiv==503) | (k_aktiv==504) | ///
(k_aktiv == 508) | (k_aktiv==509) | (k_aktiv == 510)
replace employ = 2 if (k_aktiv == 109) | (k_aktiv ==270) | (k_aktiv ==301) ///
| (k_aktiv ==302) | (k_aktiv ==303) | (k_aktiv ==304) | (k_aktiv ==305) | ///
(k_aktiv ==307) | (k_aktiv ==306)
replace employ = 3 if (k_aktiv ==501) | (k_aktiv ==502) | (k_aktiv ==503)
replace employ = 4 if (k_aktiv ==105) | (k_aktiv == 106) | (k_aktiv ==107) | (k_aktiv == 100)
replace employ = 5 if (k_aktiv ==103) | (k_aktiv ==104) | (k_aktiv == 111)
replace employ = 6 if (k_aktiv == 102)

label define employ 1 "not employed" 2 "in education" 3 "parental leave" ///
4 "underemployed" 5 "part-time" 6 "full-time", replace
label values employ employ

tab k_aktiv employ, mis


gen employ3 = .
replace employ3 = 1 if (employ==1) | (employ==2) | (employ==3)
replace employ3 = 2 if (employ==4) | (employ==5)
replace employ3 = 3 if (employ==6)

label define employ3 1 "not employed" 2 "under- or parttime" 3 "fulltime empl"
label values employ3 employ3
tab employ employ3, mis


*Income
sum k_aequi_mean_hh
gen lincome = ln(k_aequi_mean_hh)
hist lincome


save "$output\aida_panel.dta", replace
clear


*Age of youngest child in household
use "$aida2019\personen.dta", clear

sort HHLFD INTNR
egen minagehh=min(XALTER), by(HHLFD)
sum  minagehh

keep HHLFD INTNR minagehh
save "$output\aida2019_minagehh.dta"


rename HHLFD INTNR, lower
sort hhlfd intnr
save "$output\aida2019_minagehh.dta", replace
clear


use "$output\aida_panel.dta"
sort hhlfd intnr
merge 1:1 hhlfd intnr using "$output\aida2019_minagehh.dta", gen(_merge2)

keep if _merge2 == 3
drop _merge2

fre minagehh
rename minagehh ageygkid


save "$output\aida_panel.dta", replace
clear


********************************************************
**Predicting attrition
********************************************************

use "$output\aida_panel.dta"


gen parti2021 = . //binary indicator for participation in 2021
replace parti2021 = 1 if _merge == 3
replace parti2021 = 0 if _merge == 1

tab _merge parti2021
drop _merge


logit parti2021 lone i.edu3 i.employ3 i.depriv3 lincome i.anzkid3 ageygkid, or
margins, dydx(_all)
marginsplot, horizontal xline(0, lcolor(black)) yscale(reverse) recast(scatter) ///
title("") ytitle("") xtitle("") ylabel(1 "Lone mother" ///
2 "Secondary education" 3 "Tertiary education" 4 "Employed part-time" 5 "Employed full-time" ///
6 "Low deprivation" 7 "High deprivation" 8 "Income" 9 "Two children" 10 "Three + children" ///
11 "age youngest child",labsize(small) nogrid)


********************************************************
**Descriptive statistics
********************************************************

**Cronbachs alpha for text
*2019
alpha v44401_1 - v44401_5, item

*2021
alpha dep1_2021-dep5_2021, item


**Testing group differences for text
oneway sat_2019 lone, tabulate
oneway sat_2021 lone, tabulate

oneway affect_2019 lone, tabulate
oneway affect_2021 lone, tabulate


**Table 1
fre lone
fre support
fre edu3
fre employ3
fre depriv3
fre anzkid3

sum xalter sat_2019 sat_2021 affect_2019 affect_2021 ageygkid stress k_aequi_mean_hh 


bysort lone: sum xalter sat_2019 sat_2021 affect_2019 affect_2021 k_aequi_mean_hh ageygkid stress

bysort lone: fre lone
bysort lone: fre support
bysort lone: fre edu3
bysort lone: fre employ3
bysort lone: fre depriv3
bysort lone: fre anzkid3


********************************************************
**Regression models: Table 2; Figures 1-2
********************************************************

**Change in psychological well-being
*Model 1
regress affect_change i.lone i.edu3 i.employ3 i.depriv3 lincome i.anzkid3 ageygkid ib3.support stress

*Model 2
regress affect_change i.lone##ib3.support i.edu3 i.employ3 i.depriv3 lincome i.anzkid3 ageygkid stress
margins, over(support lone)
marginsplot


**Change in life satisfaction
*Model 1
regress sat_change i.lone c.stress i.edu3 i.employ3 i.depriv3 lincome i.anzkid3 ageygkid ib3.support  

*Model 2
regress sat_change i.lone##c.stress i.edu3 i.employ3 i.depriv3 lincome i.anzkid3 ageygkid ib3.support  
margins, at(stress=(1 2 3 4 5 6)) over(lone)
marginsplot


save "$output\aida_panel.dta", replace
clear
exit


********************************************************
**Note: Case numbers and decimal places may vary slightly
********from the reported numbers because versions of the
********the used datasets at the time of drafting the 
********manuscript vary slightly from the publically 
********available scientific use files. The pattern of 
********results remains unchanged.
********************************************************
